aboutsummaryrefslogtreecommitdiffstats
path: root/lib/erl_interface/test/ei_tmo_SUITE.erl
diff options
context:
space:
mode:
authorSverker Eriksson <[email protected]>2015-11-18 14:58:41 +0100
committerSverker Eriksson <[email protected]>2016-04-07 18:41:47 +0200
commit8015b8d46ff38fc05cac9cf8df9a37b5580e8909 (patch)
tree7dc5e5c78b2cd5429b5666c0cd9bdb6dc5cd506d /lib/erl_interface/test/ei_tmo_SUITE.erl
parentbd6a725af02724ca783d7026e650cd380cc1c68c (diff)
downloadotp-8015b8d46ff38fc05cac9cf8df9a37b5580e8909.tar.gz
otp-8015b8d46ff38fc05cac9cf8df9a37b5580e8909.tar.bz2
otp-8015b8d46ff38fc05cac9cf8df9a37b5580e8909.zip
erl_interface: Cuddle test ei_tmo_SUITE
Increase max number of messages sent to fill buffers.
Diffstat (limited to 'lib/erl_interface/test/ei_tmo_SUITE.erl')
-rw-r--r--lib/erl_interface/test/ei_tmo_SUITE.erl4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/erl_interface/test/ei_tmo_SUITE.erl b/lib/erl_interface/test/ei_tmo_SUITE.erl
index 5ee7198c53..aaa0992fb4 100644
--- a/lib/erl_interface/test/ei_tmo_SUITE.erl
+++ b/lib/erl_interface/test/ei_tmo_SUITE.erl
@@ -164,12 +164,12 @@ do_one_send_failure(Config,From,FakeName,CName,VxSim) ->
{term, X} = runner:get_term(P3, 10000),
true = is_integer(X),
Message = [112,term_to_binary({6,self(),'',test}),
- term_to_binary({From,10000,
+ term_to_binary({From,50000,
{app,["lapp",{sa,["att",du,{slapp,
sitta}]}]}})],
gen_tcp:send(SocketB,Message),
%% At this point the test program starts sending messages (max 10000). Since
%% we're not receiving, eventually the send buffer fills up. Then no more
%% sending is possible and select() times out. The number of messages sent
%% before this happens is returned in Iters. The timeout value for get_term/2
@@ -164,12 +164,12 @@ do_one_send_failure(Config,From,FakeName,CName,VxSim) ->
sitta}]}]}})],
gen_tcp:send(SocketB,Message),
- %% At this point the test program starts sending messages (max 10000). Since
+ %% At this point the test program starts sending messages (max 50000). Since
%% we're not receiving, eventually the send buffer fills up. Then no more
%% sending is possible and select() times out. The number of messages sent